Error

Enum Error 

pub enum Error {
    MissingDealerShare,
    UnknownPlayer,
    UnknownDealer(String),
    NumDealers(usize),
    NumPlayers(usize),
    DkgFailed,
    MissingPlayerDealing,
}
The error type for the DKG protocol.

The only error which can happen through no fault of your own is Error::DkgFailed.

Error::MissingPlayerDealing happens through mistakes or faults when the state of a player is restored after a crash.

The other errors are due to issues with configuration.

Variants



MissingDealerShare



UnknownPlayer



UnknownDealer(String)



NumDealers(usize)



NumPlayers(usize)



DkgFailed



MissingPlayerDealing

The player’s state is missing a dealing it should have.

This error is emitted when the player is missing dealings that it should otherwise have based on the flow of the protocol. This can only happen if the code in this module is used in a stateful way, restoring the state of the player from saved information. If this state is corrupted on disk, or missing, then this error can happen.