pub struct Logs<V: Variant, P: PublicKey, M: Faults> { /* private fields */ }Expand description
Accumulates dealer logs for a DKG round and caches verification results so
pre_verify work can be reused until a dealer’s log is replaced.
Implementations
Sourceimpl<V: Variant, P: PublicKey, M: Faults> Logs<V, P, M>
impl<V: Variant, P: PublicKey, M: Faults> Logs<V, P, M>
Sourcepub fn record(&mut self, dealer: P, log: DealerLog<V, P>) -> bool
pub fn record(&mut self, dealer: P, log: DealerLog<V, P>) -> bool
Record the log for a particular dealer.
Return true if the dealer was already present in the log, in which
case its log will be replaced.
Sourcepub fn pre_verify<B: BatchVerifier<PublicKey = P>>(
&mut self,
rng: &mut impl CryptoRngCore,
strategy: &impl Strategy,
)
pub fn pre_verify<B: BatchVerifier<PublicKey = P>>( &mut self, rng: &mut impl CryptoRngCore, strategy: &impl Strategy, )
Verify the logs that we’ve received so far.
This makes finalization faster, by doing some of the verification work now.
This method can amortize work over a batch of items. It’s more efficient
to call it after several Self::record, rather than after
each call.