#[repr(u8)]pub enum Mode {
NonZeroCounter = 0,
RootsOfUnity = 1,
}Expand description
Configures how participants are assigned shares of a secret.
More specifically, this configures how evaluation points of a polynomial are assigned to participant identities.
Variants
NonZeroCounter = 0
RootsOfUnity = 1
Assigns participants to powers of a root of unity.
This mode enables sub-quadratic interpolation using NTT-based algorithms.