pub struct ModeVersion(/* private fields */);Expand description
Determines which modes can be parsed.
As modes have been added over time, this versioning mechanism helps with supporting compatibility.
This allows upgrading to a new version of the library, including more modes, while using this version to determine which modes are supported at runtime.
Implementations