pub trait Namespace:
Clone
+ Send
+ Sync {
// Required method
fn derive(namespace: &[u8]) -> Self;
}Expand description
Trait for namespace types that can derive themselves from a base namespace.
This trait is implemented by namespace types to define how they are computed from a base namespace string.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".