pub struct DefaultEngine(/* private fields */);Expand description
Engine that at runtime selects the best Engine.
Implementations
Sourceimpl DefaultEngine
impl DefaultEngine
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates new DefaultEngine by chosing and initializing the underlying engine.
On x86(-64) the engine is chosen in the following order of preference:
Avx2Ssse3NoSimd
On AArch64 the engine is chosen in the following order of preference:
NeonNoSimd