NoSimd

Struct NoSimd 

pub struct NoSimd { /* private fields */ }
Optimized Engine without SIMD.

NoSimd is a basic optimized engine which works on all CPUs.

Implementations

Source

impl NoSimd

pub fn new() -> Self

Creates new NoSimd, initializing all tables needed for encoding or decoding.

Currently only difference between encoding/decoding is LogWalsh (128 kiB) which is only needed for decoding.