pub struct DecoderResult<'a> { /* private fields */ }Expand description
The restored original shards from a decode that ran (an original was missing).
Decoder::decode returns None instead when every original shard was already provided, since
there is nothing to reconstruct.
Implementations
Sourceimpl DecoderResult<'_>
impl DecoderResult<'_>
Sourcepub fn original(&self, index: usize) -> Option<&[u8]>
pub fn original(&self, index: usize) -> Option<&[u8]>
Returns restored original shard with given index
or None if given index doesn’t correspond to
a missing original shard.
Sourcepub const fn original_iter(&self) -> Originals<'_> ⓘ
pub const fn original_iter(&self) -> Originals<'_> ⓘ
Returns iterator over all restored original shards and their indexes, ordered by indexes.