pub struct EncoderResult<'a> { /* private fields */ }Expand description
Result of encoding. Contains the generated recovery shards.
This struct is created by Encoder::encode
and RateEncoder::encode.
Implementations
Sourceimpl EncoderResult<'_>
impl EncoderResult<'_>
Sourcepub fn recovery(&self, index: usize) -> Option<&[u8]>
pub fn recovery(&self, index: usize) -> Option<&[u8]>
Returns recovery shard with given index
or None if index >= recovery_count.
Recovery shards have indexes 0..recovery_count
and these same indexes must be used when decoding.
Sourcepub const fn recovery_iter(&self) -> Recovery<'_> ⓘ
pub const fn recovery_iter(&self) -> Recovery<'_> ⓘ
Returns iterator over all recovery shards ordered by their indexes.
Recovery shards have indexes 0..recovery_count
and these same indexes must be used when decoding.