Digest

Trait Digest 

pub trait Digest:
    Array
    + Copy
    + Random {
    const EMPTY: Self;
}
Specializes the commonware_utils::Array trait with the Copy trait for cryptographic digests (which should be cheap to clone).

Warning

This trait requires Random::random, but generating a digest at random is typically reserved for testing, and not production use.

Required Associated Constants

const EMPTY: Self

An empty (all-zero) digest.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Digest for commonware_cryptography::blake3::Digest

Source

const EMPTY: Self

Source

impl Digest for commonware_cryptography::crc32::Digest

Source

const EMPTY: Self

Source

impl Digest for commonware_cryptography::sha256::Digest

Source

const EMPTY: Self

Source

impl Digest for Summary

Source

const EMPTY: Self