Digestible

Trait Digestible 

pub trait Digestible:
    Clone
    + Sized
    + Send
    + Sync
    + 'static {
    type Digest: Digest;

    // Required method
    fn digest(&self) -> Self::Digest;
}
An object that can be uniquely represented as a Digest.

Required Associated Types

type Digest: Digest

The type of digest produced by this object.

Required Methods

fn digest(&self) -> Self::Digest

Returns a unique representation of the object as a Digest.

If many objects with Digests are related (map to some higher-level group Digest), you should also implement Committable.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors