Module zk

Module zk 

Modules

bulletproofs
circuit
Utilities for creating arithmetic circuits.
pedersen_to_plain
This module provides a proof that a plain commitment and a Pedersen commitment share the same committed value.