Claim

Struct Claim 

pub struct Claim<G> {
    pub commitments: Vec<G>,
}
The public claim for the protocol.

The claim consists of Pedersen commitments to values, which the prover claims satisfy a Circuit.

The claim does not contain the Circuit itself, so that the verifier is in control of what properties they want the committed values to satisfy.

Fields

commitments: Vec<G>