SparseMatrix

Struct SparseMatrix 

pub struct SparseMatrix<F> { /* private fields */ }
A sparse matrix indexed by (row, column).

Missing entries are treated as 0.

Implementations

Source

impl<F> SparseMatrix<F>

pub const fn width(&self) -> usize

The width of this matrix.

This is determined solely by the highest column with a non-zero entry.

pub const fn height(&self) -> usize

The height of this matrix.

This is determined solely by the highest row with a non-zero entry.

pub fn pad(&mut self, width: usize, height: usize)

Pad this matrix to have at least these dimensions.