Witness

Struct Witness 

pub struct Witness<F> { /* private fields */ }
A prover-side assignment for a circuit proof.

This contains the committed values, their Pedersen blindings, and the internal left, right, and output wire values.

Implementations

Source

impl<F> Witness<F>

pub fn new( values: Vec<F>, blinding: Vec<F>, left: Vec<F>, right: Vec<F>, out: Vec<F>, ) -> Option<Self>

Create a new witness, given all committed values, and internal values.

This is a very low level method, with the only safety guard being to check that certain vectors have matching lengths. Beyond that, we don’t check that the values satisfy a circuit relationship, or match the commitments.

pub fn values(&self) -> &[F]

pub fn is_satisfied(&self, circuit: &Circuit<F>) -> bool
where F: Ring,

Check whether this witness’s wires satisfy the given Circuit.

Useful as a debugging aid: if this returns false, the prover and circuit are inconsistent and any prove result will not verify.

pub fn claim<G: Space<F>>(&self, setup: &Setup<G>) -> Claim<G>

Create the public claim corresponding to this witness for the given setup.

The resulting claim contains Pedersen commitments to the witness’s committed values and blindings.