Witness

Struct Witness 

pub struct Witness<F> { /* private fields */ }
The witness contains the actual vectors a_i and b_i for the inner product argument.

This struct guarantees that their lengths are equal, and a power of two.

Implementations

Source

impl<F> Witness<F>

pub fn new(elements: impl IntoIterator<Item = (F, F)>) -> Option<Self>

Create a new witness, from the two vectors whose product we’re taking.

This function returns None if the iterator does not produce a power of two number of elements.

Source

impl<F: Field> Witness<F>

pub fn new_with_claim<G: Space<F>>( setup: &Setup<G>, y: F, elements: impl IntoIterator<Item = (F, F)>, ) -> Option<(Self, Claim<F, G>)>

Like Self::new, but also produces a Claim, for convenience.

In some situations, you have a claim from somewhere else, using the proof system in this module as just one step in some larger proof.

If you don’t have a claim, this lets you compute a valid one.

To do so, you need a Setup, which can be reused across different witnesses.