Setup

Struct Setup 

pub struct Setup<G> {
    pub value_generator: G,
    pub blinding_generator: G,
}
Generators used by the proof system.

The blinding generator must not have a known discrete-log relationship relative to the value generator.

Fields

value_generator: G

The generator used in both the plain and Pedersen commitments.

blinding_generator: G

The generator used only for the Pedersen blinding term.