pub struct Scoped<S: Scheme> { /* private fields */ }Expand description
A scheme handle returned by a Provider for one scope.
Always usable as a Verifier for certificate verification. The full signing scheme is
recoverable with Scoped::into_scheme only when the scope was built with Scoped::scheme.
A scope built with Scoped::verifier yields None.
Implementations