Module zk
commonware_
cryptography
2026.5.0
Module zk
Module Items
Modules
In crate commonware_
cryptography
commonware_cryptography
Module
zk
Modules

bulletproofs
pedersen_
to_
plain
This module provides a proof that a plain commitment and a Pedersen commitment share the same committed value.