pub struct Witness<F> { /* private fields */ }Expand description
A prover-side assignment for a circuit proof.
This contains the committed values, their Pedersen blindings, and the internal left, right, and output wire values.
Implementations
Sourceimpl<F> Witness<F>
impl<F> Witness<F>
Sourcepub fn new(
values: Vec<F>,
blinding: Vec<F>,
left: Vec<F>,
right: Vec<F>,
out: Vec<F>,
) -> Option<Self>
pub fn new( values: Vec<F>, blinding: Vec<F>, left: Vec<F>, right: Vec<F>, out: Vec<F>, ) -> Option<Self>
Create a new witness, given all committed values, and internal values.
This is a very low level method, with the only safety guard being to check that certain vectors have matching lengths. Beyond that, we don’t check that the values satisfy a circuit relationship, or match the commitments.
pub fn values(&self) -> &[F]
Sourcepub fn is_satisfied(&self, circuit: &Circuit<F>) -> boolwhere
F: Ring,
pub fn is_satisfied(&self, circuit: &Circuit<F>) -> boolwhere
F: Ring,