pub struct Setup<G> { /* private fields */ }Expand description
A setup decides on what group elements we use to commit to vectors and their product.
A setup for an inner product argument for c = <a_i, b_i> needs generators
to commit to a_i, which we call G_i, generators for b_i, which we call
H_i, and a generator for the product, c, which we call Q, or “the product generator”.
We can support inner products of different sizes, as long as we have enough generators.
To construct this type, see Self::new.
Implementations
Sourceimpl<G> Setup<G>
impl<G> Setup<G>
Sourcepub fn new(
product_generator: G,
g_and_h: impl IntoIterator<Item = (G, G)>,
) -> Self
pub fn new( product_generator: G, g_and_h: impl IntoIterator<Item = (G, G)>, ) -> Self
Create a new Setup, given specific choices of the generator.
You MUST ensure that all of the values provided to this function are unique.
Sourcepub const fn product_generator(&self) -> &G
pub const fn product_generator(&self) -> &G
The product generator Q.
Sourcepub const fn supports(&self, lg_len: u8) -> bool
pub const fn supports(&self, lg_len: u8) -> bool
Check if this setup supports claims of a given length.
Sourcepub fn eval<F: Field>(
&self,
f: impl FnOnce(&Setup<Synthetic<F, G>>) -> Option<Synthetic<F, G>>,
strategy: &impl Strategy,
) -> Option<G>where
G: Space<F>,
pub fn eval<F: Field>(
&self,
f: impl FnOnce(&Setup<Synthetic<F, G>>) -> Option<Synthetic<F, G>>,
strategy: &impl Strategy,
) -> Option<G>where
G: Space<F>,
Build a virtual setup, call f to obtain a verification equation,
and evaluate it against the concrete generators in self.
Returns None when f returns None (malformed proof).
Otherwise returns the evaluated group element, which should be
zero for a valid proof.