pub struct Selector<'ctx, F> { /* private fields */ }Expand description
A tool for selecting among multiple items.
This is a generalization of using a BoolVar to select among two items,
letting you use k bits to select among 2^k items.
Implementations
Sourceimpl<'ctx, F: Ring> Selector<'ctx, F>
impl<'ctx, F: Ring> Selector<'ctx, F>
Sourcepub fn new(bits: &[BoolVar<'ctx, F>]) -> Self
pub fn new(bits: &[BoolVar<'ctx, F>]) -> Self
Create a new selector, using a given number of in-circuit bits.
This selector will then be able to select among exactly 2^k items,
where k is the number of bits passed in here.
It is more efficient to create one selector and reuse it.
The selection is made in ascending order, i.e. 0..00, 0..01, 0..10, … In other words, if you pass in, e.g. 010 to this function, you then will always get the 3rd (index 2) of 8 items.
Sourcepub fn select_constant(&self, constants: &[F]) -> Var<'ctx, F>
pub fn select_constant(&self, constants: &[F]) -> Var<'ctx, F>
Select a constant value among 2^k possibilities.